/*
* Copyright 2009, KyTea Development Team
* 
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* 
*     http://www.apache.org/licenses/LICENSE-2.0
* 
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#ifndef KYTEA_STRUCT_H__
#define KYTEA_STRUCT_H__

#include<list>

using namespace std;

namespace kytea  {

class KyteaWord {
public:
    KyteaWord(const KyteaString & s) : surf(s), isCertain(true) { }
    KyteaString surf;
    KyteaString pron;
    double peConf;
    bool isCertain;
};

// a class holding the representation of a single sentence
class KyteaSentence {

public:

    typedef vector<KyteaWord> Words;
    typedef vector<double> Floats;

    // the original raw string
    KyteaString chars;
    Floats wsConfs;

    // the string of words
    Words words;

    void refreshWS(double confidence) {
        if(words.size() != 0) {
            // TODO: this must be implemented
            throw runtime_error("Attempt to over-write already-estimated word boundaries (to be implemented)");
        } else {
            unsigned last = 0;
            for(unsigned i = 0; i < wsConfs.size(); i++) {
                if(wsConfs[i] > confidence) {
                    KyteaWord w(chars.substr(last, i-last+1));
                    words.push_back(w);
                    last = i+1;
                }
            }
            KyteaWord w(chars.substr(last, wsConfs.size()-last+1));
            words.push_back(w);
        }
    }

};

}

#endif
